@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -76,8 +48,9 @@ import com.dropbox.core.v2.files.LookupError;
 import com.dropbox.core.v2.files.Metadata;
 import com.dropbox.core.v2.files.RelocationErrorException;
 import com.dropbox.core.v2.files.SearchErrorException;
-import com.dropbox.core.v2.files.SearchMatch;
-import com.dropbox.core.v2.files.SearchResult;
+import com.dropbox.core.v2.files.SearchMatchV2;
+import com.dropbox.core.v2.files.SearchOptions;
+import com.dropbox.core.v2.files.SearchV2Result;
 import com.dropbox.core.v2.files.ThumbnailErrorException;
 import com.dropbox.core.v2.files.ThumbnailFormat;
 import com.dropbox.core.v2.files.ThumbnailSize;
@@ -101,6 +74,7 @@ import com.openexchange.file.storage.FileStorageCaseInsensitiveAccess;
 import com.openexchange.file.storage.FileStorageExceptionCodes;
 import com.openexchange.file.storage.FileStorageFileAccess;
 import com.openexchange.file.storage.FileStorageFolder;
+import com.openexchange.file.storage.FileStoragePersistentIDs;
 import com.openexchange.file.storage.FileStorageSequenceNumberProvider;
 import com.openexchange.file.storage.FileTimedResult;
 import com.openexchange.file.storage.NameBuilder;
@@ -123,7 +97,7 @@ import com.openexchange.tools.iterator.SearchIteratorAdapter;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public class DropboxFileAccess extends AbstractDropboxAccess implements ThumbnailAware, FileStorageSequenceNumberProvider, FileStorageCaseInsensitiveAccess, FileStorageAutoRenameFoldersAccess {
+public class DropboxFileAccess extends AbstractDropboxAccess implements ThumbnailAware, FileStorageSequenceNumberProvider, FileStorageCaseInsensitiveAccess, FileStorageAutoRenameFoldersAccess, FileStoragePersistentIDs {
 
     private static final Logger LOG = LoggerFactory.getLogger(DropboxFileAccess.class);
 
@@ -187,7 +161,7 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
             //TODO: fetching all revisions just to get the number of versions is quite expensive;
             //      maybe we can introduce something like "-1" for "unknown number of versions"
             String path = toPath(folderId, id);
-            ListRevisionsResult revisions = client.files().listRevisions(path, 100);
+            ListRevisionsResult revisions = client.files().listRevisionsBuilder(path).withLimit(Long.valueOf(100)).start();
             if (revisions != null) {
                 dropboxFile.setNumberOfVersions(revisions.getEntries().size());
             }
@@ -233,12 +207,12 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
                 try {
                     if (Strings.equalsNormalizedIgnoreCase(path, toPath)) {
                         String filePath = toPath(file.getFolderId(), UUID.randomUUID().toString() + ' ' + file.getFileName());
-                        Metadata metadata = client.files().move(path, filePath);
+                        Metadata metadata = client.files().moveV2(path, filePath).getMetadata();
                         path = metadata.getPathDisplay();
                     }
 
-                    Metadata metadata = client.files().move(path, toPath);
-                    DropboxFile dbxFile = new DropboxFile((FileMetadata) metadata, userId);
+                    Metadata metadata = client.files().moveV2(path, toPath).getMetadata();
+                    DropboxFile dbxFile = new DropboxFile(FileMetadata.class.cast(metadata), userId);
                     file.copyFrom(dbxFile, copyFields);
                     return dbxFile.getIDTuple();
                 } catch (RelocationErrorException e) {
@@ -271,11 +245,11 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
             String destPath = toPath(destFolder, destName.toString());
 
             // Copy
-            Metadata metadata = client.files().copy(path, destPath);
+            Metadata metadata = client.files().copyV2(path, destPath).getMetadata();
             if (!(metadata instanceof FileMetadata)) {
                 throw FileStorageExceptionCodes.NOT_A_FILE.create(DropboxConstants.ID, destPath);
             }
-            DropboxFile dbxFile = new DropboxFile((FileMetadata) metadata, userId);
+            DropboxFile dbxFile = new DropboxFile(FileMetadata.class.cast(metadata), userId);
             if (update != null) {
                 update.copyFrom(dbxFile, copyFields);
             }
@@ -295,11 +269,11 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
         String destPath = toPath(destFolder, destName);
 
         try {
-            Metadata metadata = client.files().move(path, destPath);
+            Metadata metadata = client.files().moveV2(path, destPath).getMetadata();
             if (!(metadata instanceof FileMetadata)) {
                 throw FileStorageExceptionCodes.NOT_A_FILE.create(DropboxConstants.ID, destPath);
             }
-            DropboxFile dbxFile = new DropboxFile((FileMetadata) metadata, userId);
+            DropboxFile dbxFile = new DropboxFile(FileMetadata.class.cast(metadata), userId);
             if (update != null) {
                 update.copyFrom(dbxFile, copyFields);
             }
@@ -342,7 +316,7 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
             for (Metadata entry : entries) {
                 if (entry instanceof FileMetadata) {
                     try {
-                        client.files().delete(entry.getPathDisplay());
+                        client.files().deleteV2(entry.getPathDisplay());
                     } catch (DeleteErrorException e) {
                         LOG.debug("The file '{}' could not be deleted. Skipping.", entry.getPathDisplay(), e);
                     }
@@ -367,7 +341,7 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
             for (IDTuple id : ids) {
                 String path = toPath(id.getFolder(), id.getId());
                 try {
-                    client.files().delete(path);
+                    client.files().deleteV2(path);
                 } catch (DeleteErrorException e) {
                     LOG.debug("The file '{}' could not be deleted. Skipping.", path, e);
                     ret.add(id);
@@ -746,7 +720,7 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
 
             // Upload the remaining chunk
             long remaining = length - offset;
-            CommitInfo commitInfo = new CommitInfo(toPath(file.getFolderId(), file.getFileName()), WriteMode.OVERWRITE, false, file.getLastModified(), false);
+            CommitInfo commitInfo = new CommitInfo(toPath(file.getFolderId(), file.getFileName()), WriteMode.OVERWRITE, false, file.getLastModified(), true, null, false);
             UploadSessionFinishUploader sessionFinish = client.files().uploadSessionFinish(cursor, commitInfo);
             FileMetadata metadata = sessionFinish.uploadAndFinish(stream, remaining);
 
@@ -846,23 +820,23 @@ public class DropboxFileAccess extends AbstractDropboxAccess implements Thumbnai
      * @throws DbxException if a generic Dropbox error is occurred
      */
     private List<File> fireSearch(String folderId, String pattern, boolean includeSubfolders) throws SearchErrorException, DbxException {
-        SearchResult searchResult = client.files().searchBuilder(folderId, pattern).start();
+        SearchV2Result searchResult = client.files().searchV2Builder(pattern).withOptions(SearchOptions.newBuilder().withPath(folderId).build()).start();
 
         List<File> results = new ArrayList<>();
         boolean hasMore = false;
         do {
-            hasMore = searchResult.getMore();
-            List<SearchMatch> matches = searchResult.getMatches();
-            for (SearchMatch match : matches) {
-                Metadata metadata = match.getMetadata();
+            hasMore = searchResult.getHasMore();
+            List<SearchMatchV2> matches = searchResult.getMatches();
+            for (SearchMatchV2 match : matches) {
+                Metadata metadata = match.getMetadata().getMetadataValue();
                 String parent = getParent(metadata.getPathDisplay());
                 if (metadata instanceof FileMetadata && (includeSubfolders || folderId.equals(parent))) {
-                    results.add(new DropboxFile((FileMetadata) metadata, userId));
+                    results.add(new DropboxFile(FileMetadata.class.cast(metadata), userId));
                 }
             }
             if (hasMore) {
-                long start = searchResult.getStart();
-                searchResult = client.files().searchBuilder(folderId, pattern).withStart(L(start)).start();
+                String cursor = searchResult.getCursor();
+                searchResult = client.files().searchContinueV2(cursor);
             }
         } while (hasMore);
 
