@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -233,7 +205,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
         if (false == autoRename) {
             String fullpath = constructPath(parentId, toCreate.getName());
             try {
-                FolderMetadata folderMetadata = client.files().createFolder(fullpath);
+                FolderMetadata folderMetadata = client.files().createFolderV2(fullpath).getMetadata();
                 return folderMetadata.getPathDisplay();
             } catch (CreateFolderErrorException e) {
                 CreateFolderError error = e.errorValue;
@@ -256,7 +228,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
         NameBuilder name = null;
         while (true) {
             try {
-                FolderMetadata folderMetadata = client.files().createFolder(fullpath);
+                FolderMetadata folderMetadata = client.files().createFolderV2(fullpath).getMetadata();
                 return folderMetadata.getPathDisplay();
             } catch (CreateFolderErrorException e) {
                 CreateFolderError error = e.errorValue;
@@ -303,7 +275,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
 
         if (false == autoRename) {
             try {
-                Metadata metadata = client.files().move(folderId, newParentId);
+                Metadata metadata = client.files().moveV2Builder(folderId, newParentId).start().getMetadata();
                 return metadata.getPathDisplay();
             } catch (RelocationErrorException e) {
                 RelocationError relocationError = e.errorValue;
@@ -327,7 +299,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
         while (true) {
             try {
                 String toPath = newParentId + name.toString();
-                Metadata metadata = client.files().move(folderId, toPath);
+                Metadata metadata = client.files().moveV2Builder(folderId, toPath).start().getMetadata();
                 return metadata.getPathDisplay();
             } catch (RelocationErrorException e) {
                 RelocationError relocationError = e.errorValue;
@@ -354,7 +326,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
         String parentId = folderId.substring(0, lastIndex + 1);
         try {
             String newPath = parentId + newName;
-            Metadata metadata = client.files().move(folderId, newPath);
+            Metadata metadata = client.files().moveV2Builder(folderId, newPath).start().getMetadata();
             return metadata.getPathDisplay();
         } catch (RelocationErrorException e) {
             RelocationError relocationError = e.errorValue;
@@ -375,7 +347,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
     @Override
     public String deleteFolder(String folderId) throws OXException {
         try {
-            Metadata metadata = client.files().delete(folderId);
+            Metadata metadata = client.files().deleteV2(folderId).getMetadata();
             return metadata.getName();
         } catch (DeleteErrorException e) {
             throw DropboxExceptionHandler.handleDeleteErrorException(e, folderId, "", accountDisplayName);
@@ -396,7 +368,7 @@ public class DropboxFolderAccess extends AbstractDropboxAccess implements FileSt
             for (Metadata entry : entries) {
                 if (entry instanceof FolderMetadata) {
                     try {
-                        client.files().delete(entry.getPathDisplay());
+                        client.files().deleteV2(entry.getPathDisplay());
                     } catch (DeleteErrorException e) {
                         LOG.debug("The folder '{}' could not be deleted. Skipping.", entry.getPathDisplay(), e);
                     }
